@@ -1,11 +1,11 @@
 /*
- * $Id: TestSuite.java,v 1.11 1998/11/22 14:20:33 metlov Exp $
+ * $Id: TestSuite.java,v 1.13 1999/12/19 17:43:31 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
  *    http://galaxy.fzu.cz/JEL/
  *
- * (c) 1998 by Konstantin Metlov(metlov@fzu.cz);
+ * (c) 1998,1999 by Konstantin Metlov(metlov@fzu.cz);
  *
  * JEL is Distributed under the terms of GNU General Public License.
  *    This code comes with ABSOLUTELY NO WARRANTY.
@@ -266,7 +266,7 @@ public class TestSuite {
     // next line makes also static functions from VariablePrivider available
     staticLib[1]=vp.getClass();  
     
-    vp.x=5.0;
+    vp.xvar=5.0;
     rtp[0]=vp;
     dynamicLib[0]=vp.getClass();
     lib=new Library(staticLib,dynamicLib);
@@ -279,6 +279,12 @@ public class TestSuite {
     testExpression("7+(int)4-(int)6.0+(int)x-(int)round((double)((float)((long)x+1)+2)+3)+6",
 		   new Integer(5),null,rtp,lib,o);
 
+    o.println(); o.println("----- VARIABLE AND ARRAY ACCESS ------");
+    o.println();
+    testExpression("5*xvar-66",new Double(25-66),Double.TYPE,rtp,lib,o);
+    testExpression("5*arr[1]-66",new Double(25-66),Double.TYPE,rtp,lib,o);
+    testExpression("5*(arrs[1]+arrs[2])-66",new Double(25-66),Double.TYPE,rtp,lib,o);
+    testExpression("5*(arrs[1]+arrs[(int)round(arr[0]-arrs[2])+1])-66",new Double(25-66),Double.TYPE,rtp,lib,o);
     
     o.println(); o.println("----- TESTING COMPILED-in EXCEPTIONS (x=5)------");
     o.println();
