@@ -1,11 +1,11 @@
 /*
- * $Id: VariableProvider.java,v 1.3 1998/10/28 23:10:56 metlov Exp $
+ * $Id: VariableProvider.java,v 1.4 1999/12/19 17:43:31 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
  *    http://galaxy.fzu.cz/JEL/
  *
- * (c) 1998 by Konstantin Metlov(metlov@fzu.cz);
+ * (c) 1998,1999 by Konstantin Metlov(metlov@fzu.cz);
  *
  * JEL is Distributed under the terms of GNU General Public License.
  *    This code comes with ABSOLUTELY NO WARRANTY.
@@ -15,9 +15,20 @@
 package gnu.jel.tests;
 
 public class VariableProvider {
-  public double x;
+  public double xvar;
   
-  public double x() {return x;};
+  public double x() {return xvar;};
+
+  public double[] arr;
+
+  public static final double[] arrs={1.0,2.0,3.0};
+  
+  public VariableProvider() {
+    arr=new double[3];
+    arr[0]=4.0;
+    arr[1]=5.0;
+    arr[2]=6.0;
+  };
 
   public static int throw_arg_eq_4(int x) throws Exception {
     if (x==4) throw new Exception("An exception from testsuite.");
